embeddings.hub

Download sentence-transformers ONNX exports from the Hugging Face Hub to a local cache for embeddings.core/load-model.

Download sentence-transformers ONNX exports from the Hugging Face Hub to a
local cache for `embeddings.core/load-model`.
raw docstring

embeddings.providers

Hosted embedding providers that implement embeddings.core/EmbeddingProvider.

Hosted embedding providers that implement `embeddings.core/EmbeddingProvider`.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries