Download sentence-transformers ONNX exports from the Hugging Face Hub to a
local cache for embeddings.core/load-model.
Download sentence-transformers ONNX exports from the Hugging Face Hub to a local cache for `embeddings.core/load-model`.
Hosted embedding providers that implement embeddings.core/EmbeddingProvider.
Hosted embedding providers that implement `embeddings.core/EmbeddingProvider`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |